@@ -1,7 +1,7 @@
 package Myco::Foo;
 
 ###############################################################################
-# $Id: entity.pm,v 1.5 2006/02/27 23:03:20 sommerb Exp $
+# $Id: entity.pm,v 1.6 2006/03/19 19:34:08 sommerb Exp $
 #
 # See license and copyright near the end of this file.
 ###############################################################################
@@ -194,6 +194,6 @@ L<Myco::Entity|Myco::Entity>,
 L<Myco|Myco>,
 L<Tangram|Tangram>,
 L<Class::Tangram|Class::Tangram>,
-L<mkentity|mkentity>
+L<myco-mkentity|mkentity>
 
 =cut
